pub fn proof_from_grant(
grant: &GrantForInterfaceAuthorization,
) -> ProofOfInterfaceAuthorizationExpand description
Convert [fnet_resources::GrantForInterfaceAuthorization] to
[fnet_resources::ProofOfInterfaceAuthorization] with fewer
permissions.
Panics
Panics when the Event handle does not have the DUPLICATE right. Callers
need not worry about this if providing a grant received from
[GetAuthorizationForInterface].